#### v0.1.7 (2025-05-06)
- Ensured Read-Only For SQLite and MySQL

#### v0.1.6 (2025-04-25)
- Added Clickhouse Support

#### v0.1.5 (2025-04-22)
- Changed plotting library to plotly instead of seaborn
- Fixed labeling issues in visualizations
